# Stellar Intensity Maps
## Introduction

A stellar intensity map is a unitless 3d array of the stellar intensity
function I, as a function of (x, y) pixel coordinates and the stellar angular
diameter theta_star. Values in the map are equal to the stellar count rate in a
given pixel divided by the total stellar count rate entering the coronagraph.
Does not include reductions such as QE, as in without a coronagraph the total
of I is unity.
